summaryrefslogtreecommitdiffstats
path: root/noatun/library/noatun/pref.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/noatun/pref.h')
-rw-r--r--noatun/library/noatun/pref.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/noatun/library/noatun/pref.h b/noatun/library/noatun/pref.h
index a290e51c..fe29fdf1 100644
--- a/noatun/library/noatun/pref.h
+++ b/noatun/library/noatun/pref.h
@@ -64,10 +64,10 @@ public:
* arguments are short and long descriptions
* for this module, respectively
*
* tqparent is the object that is this modules virtual-tqparent.
* When that is deleted, this also will go away, automagically.
**/
- CModule(const TQString &name, const TQString &description, const TQString &icon, TQObject *tqparent=0);
+ CModule(const TQString &name, const TQString &description, const TQString &icon, TQObject *parent=0);
virtual ~CModule();
@@ -64,10 +64,10 @@ public:
* for this module, respectively
*
- * tqparent is the object that is this modules virtual-tqparent.
+ * parent is the object that is this modules virtual-parent.
* When that is deleted, this also will go away, automagically.
**/